aboutsummaryrefslogtreecommitdiffstats
path: root/lib/public
diff options
context:
space:
mode:
authorRoeland Jago Douma <roeland@famdouma.nl>2016-09-15 11:26:24 +0200
committerRoeland Jago Douma <roeland@famdouma.nl>2016-09-15 13:11:36 +0200
commit7c078a81b4d55caa9f0381d11a27cfe5e5f1c31a (patch)
treee499f927259148b62c7327282b7bc3b1d552479b /lib/public
parent4fdee00c275c3a16381301d36635b7b0f5398751 (diff)
downloadnextcloud-server-7c078a81b4d55caa9f0381d11a27cfe5e5f1c31a.tar.gz
nextcloud-server-7c078a81b4d55caa9f0381d11a27cfe5e5f1c31a.zip
Add trict CSP to OCS responses
If a repsonse now explicitly has the Empty CSP set then the middleware won't touch it.
Diffstat (limited to 'lib/public')
-rw-r--r--lib/public/AppFramework/Http/Response.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/public/AppFramework/Http/Response.php b/lib/public/AppFramework/Http/Response.php
index 0b162b453a0..8591d6abc68 100644
--- a/lib/public/AppFramework/Http/Response.php
+++ b/lib/public/AppFramework/Http/Response.php
@@ -248,18 +248,18 @@ class Response {
/**
* Set a Content-Security-Policy
* @param ContentSecurityPolicy $csp Policy to set for the response object
* @return $this
* @since 8.1.0
*/
- public function setContentSecurityPolicy(ContentSecurityPolicy $csp) {
+ public function setContentSecurityPolicy(EmptyContentSecurityPolicy $csp) {
$this->contentSecurityPolicy = $csp;
return $this;
}
/**
* Get the currently used Content-Security-Policy
* @return ContentSecurityPolicy|null Used Content-Security-Policy or null if
* none specified.
* @since 8.1.0
*/
@@ -248,18 +248,18 @@ class Response {
/**
* Set a Content-Security-Policy
- * @param ContentSecurityPolicy $csp Policy to set for the response object
+ * @param EmptyContentSecurityPolicy $csp Policy to set for the response object
* @return $this
* @since 8.1.0
@@ -248,18 +248,18 @@ class Response {
/**
* Get the currently used Content-Security-Policy
- * @return ContentSecurityPolicy|null Used Content-Security-Policy or null if
+ * @return EmptyContentSecurityPolicy|null Used Content-Security-Policy or null if
* none specified.
* @since 8.1.0